==> mobile_pos-0.8.16.tar.gz: lib/src/views/request_pos/request_pos_index.dart <==
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/shared_widgets/raven_money_text.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_close_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/request_pos/request_terminal_1.dart';
import 'package:mobile_pos/src/views/request_pos/update_user_info.dart';
import 'package:mobile_pos/src/views/request_pos/widget/request_pos_widget.dart';

class RequestPosIndex extends StatefulWidget {
  final bool updateUserInfo;
  const RequestPosIndex({super.key, required this.updateUserInfo});

  @override
  State<RequestPosIndex> createState() => _RequestPosIndexState();
}

class _RequestPosIndexState extends State<RequestPosIndex> {
  final pageController = PageController();

  @override
  Widget build(BuildContext context) {
    return RavenPayScaffold(
        backgroundColor: pluginTheme.primaryColor,
        bottomSheet: Container(
          color: pluginTheme.primaryColor,
          child: Container(
            color: pluginTheme.onPrimary.withOpacity(0.1),
            padding: const EdgeInsets.symmetric(horizontal: 24),
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: [
                const Gap(12),
                const RequestPosListItem2(
                  title: "Transaction fees 0.35% + 5 NGN",
                ),
                Divider(color: pluginTheme.onPrimary.withOpacity(0.5)),
                const RequestPosListItem2(
                  title: "Capped at 55 NGN",
                ),
                const Gap(16),
                RavenPayButton(
                  textColor: pluginTheme.primaryColor,
                  buttonColor: pluginTheme.onPrimary,
                  onPressed: () {
                    widget.updateUserInfo
                        ? pushRoute(context, const UpdateUserInfo())
                        : pushRoute(context, const RequestTerminal1());
                  },
                  buttonText: "Request a BankBox",
                ),
                if (Platform.isIOS) ...[const Gap(28)] else ...[const Gap(12)]
              ],
            ),
          ),
        ),
        body: Padding(
          padding: const EdgeInsets.symmetric(horizontal: 24),
          child: Column(
            children: [
              const Gap(24),
              Row(
                children: [
                  RavenPayCloseButton(
                    iconColor: pluginTheme.onPrimary,
                    textColor: pluginTheme.onPrimary,
                    boxShadow: const [],
                    color: pluginTheme.onPrimary.withOpacity(0.2),
                    text: "Select a terminal",
                    isArrow: true,
                  ),
                  const Spacer(),
                  Container(
                      decoration: BoxDecoration(
                          borderRadius: BorderRadius.circular(16),
                          color: pluginTheme.onPrimary.withOpacity(0.2)),
                      padding: const EdgeInsets.symmetric(
                              horizontal: 10, vertical: 6) +
                          const EdgeInsets.only(top: 2),
                      child: Text("Full Ownership".toUpperCase(),
                          style: bodyText.copyWith(
                              fontWeight: FontWeight.w400,
                              fontSize: 10,
                              color: pluginTheme.onPrimary)))
                ],
              ),
              const Gap(24),
              const Expanded(child: BankBoxView()),
            ],
          ),
        ));
  }
}

class BankBoxView extends StatelessWidget {
  const BankBoxView({
    super.key,
  });

  @override
  Widget build(BuildContext context) {
    return SingleChildScrollView(
      child: Column(
        children: [
          ClipRRect(
            borderRadius: BorderRadius.circular(2000),
            child: Container(
                padding: const EdgeInsets.only(top: 24),
                height: 200,
                width: 200,
                decoration: BoxDecoration(
                    shape: BoxShape.circle,
                    color: pluginTheme.onPrimary.withOpacity(0.1)),
                child: Image.asset(loadAsset("request_bankbox.gif"))),
          ),
          const Gap(12),
          Align(
            alignment: Alignment.centerLeft,
            child: Container(
                padding:
                    const EdgeInsets.symmetric(horizontal: 12, vertical: 8),
                decoration: BoxDecoration(
                    color: AppColors.darkGrey,
                    borderRadius: BorderRadius.circular(16)),
                child: Row(
                  mainAxisSize: MainAxisSize.min,
                  children: [
                    Text("Price:",
                        style: bodyText.copyWith(
                            color: pluginTheme.onPrimary, fontSize: 12)),
                    const Gap(4),
                    RavenPayMoneyWidget(
                      amount: "20000",
                      fontSize: 12,
                      color: pluginTheme.onPrimary,
                    )
                  ],
                )),
          ),
          const Gap(8),
          Align(
            alignment: Alignment.centerLeft,
            child: Text("Raven BankBox",
                style: headling1.copyWith(
                    color: pluginTheme.onPrimary, fontSize: 24)),
          ),
          const Gap(12),
          Container(
              padding: const EdgeInsets.symmetric(horizontal: 14, vertical: 12),
              decoration: BoxDecoration(
                  color: pluginTheme.onPrimary,
                  borderRadius: BorderRadius.circular(12)),
              child: Column(
                children: [
                  const RequestPostItem(
                    title: "Extended 72-hour battery life on a single charge.",
                  ),
                  const RequestPostItem(
                    title: "NFC Tap to pay & Card Insert Support",
                  ),
                  const RequestPostItem(
                    title: "Compatible with all Android and iOS devices",
                  ),
                  const RequestPostItem(
                    title: "Supports E-receipts to WhatsApp and Email",
                  ),
                  RequestPostItem(
                    title: "",
                    widget: Row(children: [
                      Text("Supports",
                          style: bodyText.copyWith(
                              fontWeight: FontWeight.w500,
                              fontSize: 14,
                              color: AppColors.darkGrey)),
                      const Gap(12),
                      Image.asset(
                        loadAsset("all_card.png"),
                        height: 24,
                      )
                    ]),
                  )
                ],
              )),
          const Gap(200),
        ],
      ),
    );
  }
}

==> mobile_pos-0.8.18.tar.gz: lib/src/views/request_pos/request_pos_index.dart <==
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/shared_widgets/raven_money_text.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_close_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/request_pos/request_terminal_1.dart';
import 'package:mobile_pos/src/views/request_pos/update_user_info.dart';
import 'package:mobile_pos/src/views/request_pos/widget/request_pos_widget.dart';

class RequestPosIndex extends StatefulWidget {
  final bool updateUserInfo;
  const RequestPosIndex({super.key, required this.updateUserInfo});

  @override
  State<RequestPosIndex> createState() => _RequestPosIndexState();
}

class _RequestPosIndexState extends State<RequestPosIndex> {
  final pageController = PageController();

  @override
  Widget build(BuildContext context) {
    return RavenPayScaffold(
        backgroundColor: pluginTheme.primaryColor,
        bottomSheet: Container(
          color: pluginTheme.primaryColor,
          child: Container(
            color: pluginTheme.onPrimary.withOpacity(0.1),
            padding: const EdgeInsets.symmetric(horizontal: 24),
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: [
                const Gap(12),
                RequestPosListItem2(
                  item: Row(
                    children: [
                      Text("Transaction fees",
                          style: bodyText.copyWith(
                              color: pluginTheme.onPrimary, fontSize: 12)),
                      const Gap(3),
                      Text("0.35% + 5 NGN",
                          style: bodyText.copyWith(
                              fontWeight: FontWeight.w700,
                              color: Colors.white,
                              fontSize: 14)),
                      const Gap(3),
                      Text("capped at",
                          style: bodyText.copyWith(
                              color: pluginTheme.onPrimary, fontSize: 12)),
                      const Gap(3),
                      Text("55 NGN",
                          style: bodyText.copyWith(
                              fontWeight: FontWeight.w700,
                              color: Colors.white,
                              fontSize: 12))
                    ],
                  ),
                ),
                const Gap(16),
                RavenPayButton(
                  textColor: pluginTheme.primaryColor,
                  buttonColor: pluginTheme.onPrimary,
                  onPressed: () {
                    widget.updateUserInfo
                        ? pushRoute(context, const UpdateUserInfo())
                        : pushRoute(context, const RequestTerminal1());
                  },
                  buttonText: "Request a BankBox",
                ),
                if (Platform.isIOS) ...[const Gap(28)] else ...[const Gap(12)]
              ],
            ),
          ),
        ),
        body: Padding(
          padding: const EdgeInsets.symmetric(horizontal: 24),
          child: Column(
            children: [
              const Gap(24),
              Row(
                children: [
                  RavenPayCloseButton(
                    iconColor: pluginTheme.onPrimary,
                    textColor: pluginTheme.onPrimary,
                    boxShadow: const [],
                    color: pluginTheme.onPrimary.withOpacity(0.2),
                    text: "Select a terminal",
                    isArrow: true,
                  ),
                  const Spacer(),
                  Container(
                      decoration: BoxDecoration(
                          borderRadius: BorderRadius.circular(16),
                          color: pluginTheme.onPrimary.withOpacity(0.2)),
                      padding: const EdgeInsets.symmetric(
                              horizontal: 10, vertical: 6) +
                          const EdgeInsets.only(top: 2),
                      child: Text("Full Ownership".toUpperCase(),
                          style: bodyText.copyWith(
                              fontWeight: FontWeight.w400,
                              fontSize: 10,
                              color: pluginTheme.onPrimary)))
                ],
              ),
              const Gap(24),
              const Expanded(child: BankBoxView()),
            ],
          ),
        ));
  }
}

class BankBoxView extends StatelessWidget {
  const BankBoxView({
    super.key,
  });

  @override
  Widget build(BuildContext context) {
    return SingleChildScrollView(
      child: Column(
        children: [
          ClipRRect(
            borderRadius: BorderRadius.circular(2000),
            child: Container(
                padding: const EdgeInsets.only(top: 24),
                height: 200,
                width: 200,
                decoration: BoxDecoration(
                    shape: BoxShape.circle,
                    color: pluginTheme.onPrimary.withOpacity(0.1)),
                child: Image.asset(loadAsset("request_bankbox.gif"))),
          ),
          const Gap(12),
          Align(
            alignment: Alignment.centerLeft,
            child: Container(
                padding:
                    const EdgeInsets.symmetric(horizontal: 12, vertical: 8),
                decoration: BoxDecoration(
                    color: AppColors.darkGrey,
                    borderRadius: BorderRadius.circular(16)),
                child: Row(
                  mainAxisSize: MainAxisSize.min,
                  children: [
                    Text("Price:",
                        style: bodyText.copyWith(
                            color: pluginTheme.onPrimary, fontSize: 12)),
                    const Gap(4),
                    RavenPayMoneyWidget(
                      amount: "20000",
                      fontSize: 12,
                      color: pluginTheme.onPrimary,
                    )
                  ],
                )),
          ),
          const Gap(8),
          Align(
            alignment: Alignment.centerLeft,
            child: Text("Raven BankBox",
                style: headling1.copyWith(
                    color: pluginTheme.onPrimary, fontSize: 24)),
          ),
          const Gap(12),
          Container(
              padding: const EdgeInsets.symmetric(horizontal: 14, vertical: 12),
              decoration: BoxDecoration(
                  color: pluginTheme.onPrimary,
                  borderRadius: BorderRadius.circular(12)),
              child: Column(
                children: [
                  const RequestPostItem(
                    title: "Extended 72-hour battery life on a single charge.",
                  ),
                  const RequestPostItem(
                    title: "NFC Tap to pay & Card Insert Support",
                  ),
                  const RequestPostItem(
                    title: "Compatible with all Android and iOS devices",
                  ),
                  const RequestPostItem(
                    title: "Supports E-receipts to WhatsApp and Email",
                  ),
                  RequestPostItem(
                    title: "",
                    widget: Row(children: [
                      Text("Supports",
                          style: bodyText.copyWith(
                              fontWeight: FontWeight.w500,
                              fontSize: 14,
                              color: AppColors.darkGrey)),
                      const Gap(12),
                      Image.asset(
                        loadAsset("all_card.png"),
                        height: 24,
                      )
                    ]),
                  )
                ],
              )),
          const Gap(200),
        ],
      ),
    );
  }
}
